@@ -1,9 +1,8 @@
 use super::*;
 
-pub struct FilterScanState<S: FilterScanFn> {
-    first: Option<S::OutputItem>,
-    next: S,
-}
+pub struct FilterScanWrap<S: FilterScanFn>(S);
+
+pub type FilterScanState<S> = OptionList<<S as FilterScanFn>::OutputItem, FilterScanWrap<S>>;
 
 pub trait FilterScanFn: Sized {
     type InputItem;
@@ -12,25 +11,24 @@ pub trait FilterScanFn: Sized {
     type OutputResult;
     fn map_input(self, input: Self::InputItem) -> FilterScanState<Self>;
     fn map_result(self, result: Self::InputResult) -> Self::OutputResult;
+    fn some(self, first: Self::OutputItem) -> FilterScanState<Self> {        
+        OptionList::Some { first, end: FilterScanWrap(self) }
+    }
+    fn end(self) -> FilterScanState<Self> {
+        OptionList::End(FilterScanWrap(self))
+    }
 }
 
-pub struct FilterScanWrap<S: FilterScanFn>(S);
-
 impl<S: FilterScanFn> FlatScanFn for FilterScanWrap<S> {
     type InputItem = S::InputItem;
     type InputResult = S::InputResult;
     type OutputList = OptionList<S::OutputItem, Self>;
-    type EndList = OptionList<S::OutputItem, S::OutputResult>;
+    type EndList = OptionList<S::OutputItem, Id<S::OutputResult>>;
     fn map_item(self, input: Self::InputItem) -> Self::OutputList {
-        let FilterScanState { first, next } = self.0.map_input(input);
-        let end = FilterScanWrap(next);
-        match first {
-            Some(first) => OptionList::Some { first, end },
-            None => OptionList::End(end),
-        }
+        self.0.map_input(input)
     }
     fn map_result(self, result: Self::InputResult) -> Self::EndList {
-        OptionList::End(self.0.map_result(result))
+        OptionList::End(Id::new(self.0.map_result(result)))
     }
 }
 
